#ifdef __cplusplus
extern "C" {
#endif

GSList *get_attr_list(char * object, char * attr_type);

GSList * get_mntnfy_vector(GSList * mntners);

GSList *get_mntners(char * object);

char * send_and_get(char * host, int port, char * arg);

char * find_email_address(const char * from_line);

char * get_class_type_char(char * object);

char * UP_remove_EOLs(char * arg);

char * UP_replace_strings(char * str, const char * erase_str, const char * insert_str);

char * UP_put_assigned_NIC(char * arg, const char * assigned_NIC);

char * UP_get_current_date();

char * UP_filter_out_same_origins(char * objects, char * object);

int UP_is_object(const char * arg);

#ifdef __cplusplus
}
#endif

GSList * take_objects(char * arg);

char * UP_replace_globals(const char * arg);

GSList * get_updto_vector(GSList * mntners);

char * delete_delete_attrib(char * arg);

char * delete_override(char * arg);
